Phrase

Type Alias Phrase 

pub type Phrase = [Token];
A sequence of Tokens representing a phrase, usually produced using tokenize.

The owned representation of a Phrase is Vec<Token>. A Phrase occurs as a State item or as an input or output item in a Rule.